MCS_POLYGON_MAIN_API = "https://api.multichain.storage/api/"
MCS_POLYGON_MUMBAI_API = "https://calibration-mcs-api.filswan.com/api/"
MCS_BSC_API = 'https://calibration-mcs-bsc.filswan.com/api/'
REST_API_VERSION = "v1"
GET = "GET"
POST = "POST"
DELETE = "DELETE"
FIL_PRICE_API = "https://api.filswan.com/stats/storage"
# mcs api
MCS_PARAMS = "/common/system/params"
PRICE_RATE = "/billing/price/filecoin"
PAYMENT_INFO = "/billing/deal/lockpayment/info"
TASKS_DEALS = "/storage/tasks/deals"
MINT_INFO = "/storage/mint/info"
UPLOAD_FILE = "/storage/ipfs/upload"
DEAL_DETAIL = "/storage/deal/detail/"
USER_REGISTER = "/user/register"
USER_LOGIN = "/user/login_by_metamask_signature"
# contract
USDC_ABI = "ERC20.json"
SWAN_PAYMENT_ABI = "SwanPayment.json"
MINT_ABI = "SwanNFT.json"

CONTRACT_TIME_OUT = 300
